Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4941)

Unified Diff: chrome/common/render_messages_internal.h

Issue 4815001: Use inner HWND for accelerated rendering on windows (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/gpu_messages_internal.h ('k') | chrome/gpu/gpu_channel.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/render_messages_internal.h
===================================================================
--- chrome/common/render_messages_internal.h (revision 67491)
+++ chrome/common/render_messages_internal.h (working copy)
@@ -1315,10 +1315,10 @@
IPC_MESSAGE_ROUTED1(ViewHostMsg_UpdateRect,
ViewHostMsg_UpdateRect_Params)
- // Sent by the renderer when GPU compositing is enabled or disabled to notify
- // the browser whether or not is should do paiting.
- IPC_MESSAGE_ROUTED1(ViewHostMsg_GpuRenderingActivated,
- bool /* true if the GPU process renders to window */)
+ // Sent by the renderer when accelerated compositing is enabled or disabled to
+ // notify the browser whether or not is should do painting.
+ IPC_MESSAGE_ROUTED1(ViewHostMsg_DidActivateAcceleratedCompositing,
+ bool /* true if the accelerated compositor is actve */)
// Acknowledges receipt of a ViewMsg_HandleInputEvent message.
// Payload is a WebInputEvent::Type which is the type of the event, followed
« no previous file with comments | « chrome/common/gpu_messages_internal.h ('k') | chrome/gpu/gpu_channel.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698